/* --------------------------------------------------------------- */
/* Licensed Materials - Property of IBM                            */
/* 5724-S84                                                        */
/* (C) Copyright IBM Corp. 2006,2007, All Rights Reserved          */
/* US Government Users Restricted Rights - Use, duplication or     */
/* disclosure restricted by GSA ADP Schedule Contract with         */
/* IBM Corp.                                                       */
/* --------------------------------------------------------------- */
/* PROLOG END TAG zYx                                              */
/*
 * FILE:        spu_timer.h
 *
 * DESCRIPTION:
 *              Definitions for SPU Timer API
 */
#ifndef _SPU_TIMER_H_
#define _SPU_TIMER_H_

#include <inttypes.h>

/* clock services */
extern void spu_clock_start(void);
extern int  spu_clock_stop(void);
extern uint64_t spu_clock_read(void);

/* timer services */
extern int spu_timer_alloc(int interval, void (*func)(int));
extern int spu_timer_free(int id);
extern int spu_timer_start(int id);
extern int spu_timer_stop(int id);

/* interrupt services */
extern void spu_slih_register(unsigned event_mask, unsigned(*slih)(unsigned));
extern unsigned spu_clock_slih(unsigned event_mask);

/* number of supported timers */
#define SPU_TIMER_NTIMERS               4

/* clock error codes */
#define SPU_CLOCK_ERR_NOT_RUNNING       -2
#define SPU_CLOCK_ERR_STILL_RUNNING     -3
#define SPU_CLOCK_ERR_TIMERS_ACTIVE     -4

/* timer error codes */
#define SPU_TIMER_ERR_INVALID_PARM      -10
#define SPU_TIMER_ERR_NONE_FREE         -11
#define SPU_TIMER_ERR_INVALID_ID        -12
#define SPU_TIMER_ERR_ACTIVE            -13
#define SPU_TIMER_ERR_NOT_ACTIVE        -14
#define SPU_TIMER_ERR_NOCLOCK           -15
#define SPU_TIMER_ERR_FREE              -16
#define SPU_TIMER_ERR_NOT_STOPPED       -17

#endif
